@@ -13,10 +13,6 @@ def validate_args(args: argparse.Namespace):
     :param args: the arguments to validate
     """
 
-    if args.details and "none" in args.details:
-        logger.info("Showing no details as `none` specified.")
-        args.details = None
-
     if args.details and args.multi_cols:
         logger.info("Cannot have multiple columns in detailed view.")
         args.multi_cols = False
